@@ -1,4 +1,4 @@
-from IPython.kernel.zmq.kernelbase import Kernel
+from ipykernel.kernelbase import Kernel
 
 from os import unlink, environ
 
@@ -8,10 +8,10 @@ import re
 import signal
 import urllib
 
-from . import powershell_repl, powershell_proxy
-from .util import get_powershell
+from powershell_kernel import subprocess_repl, powershell_proxy
+from powershell_kernel.util import get_powershell
 
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 
 version_pat = re.compile(r'version (\d+(\.\d+)+)')
 
@@ -46,7 +46,7 @@ class PowerShellKernel(Kernel):
         except:
             powershell_command = get_powershell()
 
-        repl = powershell_repl.PowershellRepl('utf8', cmd=[powershell_command, '-noprofile', '-File', '-'])
+        repl = subprocess_repl.SubprocessRepl([powershell_command, '-noprofile', '-File', '-'])
         self.proxy = powershell_proxy.ReplProxy(repl)
 
     def do_execute(self, code, silent, store_history=True,
